@@ -87,7 +87,6 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             pub use checkout_core::error::new_server_error;
             pub use checkout_core::server::Server;
             pub use checkout_core::internal_context::InternalContext;
-            pub use checkout_core::pubsub_server;
 
             use std::env;
             use tokio::task;
@@ -703,10 +702,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 let pubsub_client = internal_context.pubsub_client.clone();
                 pubsub_client.spawn_token_renew(checkout_server::Duration::from_secs(15 * 60));
 
-                // start experiment
-                // checkout_server::start_payment_processing(internal_context.clone(), context_provider.clone());
-                checkout_server::pubsub_server::start_payment_processing(internal_context.clone(), &self);
-                // end experiment
+                checkout_server::start_payment_processing(internal_context.clone(), context_provider.clone());
 
                 checkout_server::HttpServerStarter::new(
                     &checkout_server::ConfigDropshot {
